@@ -1,3 +1,12 @@
+(**************************************************************************)
+(*    Lablgtk - Examples                                                  *)
+(*                                                                        *)
+(*    There is no specific licensing policy, but you may freely           *)
+(*    take inspiration from the code, and copy parts of it in your        *)
+(*    application.                                                        *)
+(*                                                                        *)
+(**************************************************************************)
+
 (* Copyright 2001 David MENTRE *)
 (* This program is under GNU GPL license *)
 
@@ -100,6 +109,6 @@ let main () =
   let w = createGLWindow "Tutorial 3" 640 480 16 false in
   GMain.Main.main ()
 
-let () = if not !Sys.interactive then Printexc.print main ()
+let _ = Printexc.print main ()
 
 
