@@ -1,4 +1,26 @@
-(* $Id: gMenu.ml,v 1.30 2005/10/25 01:22:14 garrigue Exp $ *)
+(**************************************************************************)
+(*                Lablgtk                                                 *)
+(*                                                                        *)
+(*    This program is free software; you can redistribute it              *)
+(*    and/or modify it under the terms of the GNU Library General         *)
+(*    Public License as published by the Free Software Foundation         *)
+(*    version 2, with the exception described in file COPYING which       *)
+(*    comes with the library.                                             *)
+(*                                                                        *)
+(*    This program is distributed in the hope that it will be useful,     *)
+(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
+(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
+(*    GNU Library General Public License for more details.                *)
+(*                                                                        *)
+(*    You should have received a copy of the GNU Library General          *)
+(*    Public License along with this program; if not, write to the        *)
+(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
+(*    Boston, MA 02111-1307  USA                                          *)
+(*                                                                        *)
+(*                                                                        *)
+(**************************************************************************)
+
+(* $Id$ *)
 
 open Gaux
 open Gobject
@@ -169,7 +191,6 @@ let menu ?accel_path ?border_width ?packing ?show () =
 class option_menu obj = object
   inherit GButton.button_skel obj
   method connect = new GButton.button_signals obj
-  method event = new GObj.event_ops obj
   method set_menu (menu : menu) = set OptionMenu.P.menu obj menu#as_menu
   method get_menu = new menu (get OptionMenu.P.menu obj)
   method remove_menu () = OptionMenu.remove_menu obj
