@@ -1,4 +1,26 @@
-(* $Id: gObj.mli,v 1.59 2004/11/18 12:30:39 oandrieu Exp $ *)
+(**************************************************************************)
+(*                Lablgtk                                                 *)
+(*                                                                        *)
+(*    This program is free software; you can redistribute it              *)
+(*    and/or modify it under the terms of the GNU Library General         *)
+(*    Public License as published by the Free Software Foundation         *)
+(*    version 2, with the exception described in file COPYING which       *)
+(*    comes with the library.                                             *)
+(*                                                                        *)
+(*    This program is distributed in the hope that it will be useful,     *)
+(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
+(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
+(*    GNU Library General Public License for more details.                *)
+(*                                                                        *)
+(*    You should have received a copy of the GNU Library General          *)
+(*    Public License along with this program; if not, write to the        *)
+(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
+(*    Boston, MA 02111-1307  USA                                          *)
+(*                                                                        *)
+(*                                                                        *)
+(**************************************************************************)
+
+(* $Id$ *)
 
 open Gtk
 
@@ -20,20 +42,24 @@ class gobject_ops : 'a obj ->
     method thaw_notify : unit -> unit
   end
 
-class ['a] gobject_signals : ?after:bool -> 'a obj ->
+class ['a] gobject_signals : 'a obj ->
   object ('b)
     val obj : 'a obj
     val after : bool
     method after : 'b
     method private connect :
-        'c. ('a,'c) GtkSignal.t -> callback:'c -> GtkSignal.id
+      'c. ('a,'c) GtkSignal.t -> callback:'c -> GtkSignal.id
+    method private notify :
+      'b. ('a, 'b) Gobject.property -> callback:('b -> unit) -> GtkSignal.id
   end
 
 (** {3 GtkObject} *)
 
 class type ['a] objvar = object
   val obj : 'a obj
+  (* needed for pre 3.10
   method private obj : 'a obj
+  *)
 end
 
 class gtkobj : ([> `gtk] as 'a) obj ->
@@ -43,7 +69,7 @@ class gtkobj : ([> `gtk] as 'a) obj ->
     method get_oid : int
   end
 
-class gtkobj_signals_impl : ?after:bool -> ([>`gtk] as 'a) obj ->
+class gtkobj_signals_impl : ([>`gtk] as 'a) obj ->
   object ('b)
     inherit ['a] gobject_signals
     method destroy : callback:(unit -> unit) -> GtkSignal.id
@@ -57,7 +83,7 @@ class type gtkobj_signals =
 
 (** {3 GtkWidget} *)
 
-class event_signals : ?after:bool -> [> widget] obj ->
+class event_signals : [> widget] obj ->
   object ('a)
     method after : 'a
     method any :
@@ -67,6 +93,7 @@ class event_signals : ?after:bool -> [> widget] obj ->
     method button_press : callback:(GdkEvent.Button.t -> bool) -> GtkSignal.id
     method button_release :
 	callback:(GdkEvent.Button.t -> bool) -> GtkSignal.id
+    method client : callback:(GdkEvent.Client.t -> bool) -> GtkSignal.id
     method configure : callback:(GdkEvent.Configure.t -> bool) -> GtkSignal.id
     method delete : callback:([`DELETE] Gdk.event -> bool) -> GtkSignal.id
     method destroy : callback:([`DESTROY] Gdk.event -> bool) -> GtkSignal.id
@@ -88,6 +115,8 @@ class event_signals : ?after:bool -> [> widget] obj ->
 	callback:(GdkEvent.Proximity.t -> bool) -> GtkSignal.id
     method proximity_out :
 	callback:(GdkEvent.Proximity.t -> bool) -> GtkSignal.id
+    method scroll :
+	callback:(GdkEvent.Scroll.t -> bool) -> GtkSignal.id
     method selection_clear :
 	callback:(GdkEvent.Selection.t -> bool) -> GtkSignal.id
     method selection_notify :
@@ -95,6 +124,10 @@ class event_signals : ?after:bool -> [> widget] obj ->
     method selection_request :
 	callback:(GdkEvent.Selection.t -> bool) -> GtkSignal.id
     method unmap : callback:([`UNMAP] Gdk.event -> bool) -> GtkSignal.id
+    method visibility_notify :
+	callback:(GdkEvent.Visibility.t -> bool) -> GtkSignal.id
+    method window_state :
+	callback:(GdkEvent.WindowState.t -> bool) -> GtkSignal.id
   end
 
 class event_ops : [> widget] obj ->
@@ -183,6 +216,7 @@ and misc_ops : Gtk.widget obj ->
     method add_selection_target :
       target:string -> ?info:int -> Gdk.atom -> unit
     method allocation : rectangle
+    method clear_selection_targets : Gdk.atom -> unit
     method colormap : Gdk.colormap
     method connect : misc_signals
     method convert_selection : target:string -> ?time:int32 -> Gdk.atom -> bool
@@ -192,6 +226,7 @@ and misc_ops : Gtk.widget obj ->
     method grab_default : unit -> unit
     method grab_focus : unit -> unit
     method grab_selection : ?time:int32 -> Gdk.atom -> bool
+    method has_tooltip : bool
     method hide : unit -> unit
     method hide_all : unit -> unit
     method intersect : Gdk.Rectangle.t -> Gdk.Rectangle.t option
@@ -218,6 +253,7 @@ and misc_ops : Gtk.widget obj ->
     method set_can_default : bool -> unit
     method set_can_focus : bool -> unit
     method set_double_buffered : bool -> unit
+    method set_has_tooltip : bool -> unit
     method set_name : string -> unit
     method set_sensitive : bool -> unit
     method set_size_chars :
@@ -226,9 +262,13 @@ and misc_ops : Gtk.widget obj ->
     method set_state : Tags.state_type -> unit
     method set_style : style -> unit
     method set_size_request : ?width:int -> ?height:int -> unit -> unit
+    method set_tooltip_markup : string -> unit
+    method set_tooltip_text : string -> unit
     method show : unit -> unit
     method show_all : unit -> unit
     method style : style
+    method tooltip_markup : string
+    method tooltip_text : string
     method toplevel : widget
     method unmap : unit -> unit
     method unparent : unit -> unit
@@ -251,12 +291,14 @@ and widget : ([> Gtk.widget] as 'a) obj ->
   end
 
 (** @gtkdoc gtk GtkWidget *)
-and misc_signals : ?after:bool -> Gtk.widget obj ->
+and misc_signals : Gtk.widget obj ->
   object ('b)
     inherit gtkobj_signals 
     method hide : callback:(unit -> unit) -> GtkSignal.id
     method map : callback:(unit -> unit) -> GtkSignal.id
     method parent_set : callback:(widget option -> unit) -> GtkSignal.id
+    method query_tooltip :
+      callback:(x:int -> y:int -> kbd:bool -> tooltip -> bool) -> GtkSignal.id
     method realize : callback:(unit -> unit) -> GtkSignal.id
     method unrealize : callback:(unit -> unit) -> GtkSignal.id
     method selection_get :
