@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gTree.mli 1454 2009-05-12 10:19:38Z garrigue $ *)
+(* $Id$ *)
 
 open Gobject
 open Gtk
@@ -371,6 +371,17 @@ class view_signals : [> tree_view] obj ->
       callback:(tree_iter -> tree_path -> bool) -> GtkSignal.id
     method toggle_cursor_row : callback:(unit -> bool) -> GtkSignal.id
     method unselect_all : callback:(unit -> bool) -> GtkSignal.id
+    method notify_enable_search : callback:(bool -> unit) -> GtkSignal.id
+    method notify_fixed_height_mode : callback:(bool -> unit) -> GtkSignal.id
+    method notify_hadjustment : callback:(GData.adjustment -> unit) -> GtkSignal.id
+    method notify_headers_visible : callback:(bool -> unit) -> GtkSignal.id
+    method notify_hover_expand : callback:(bool -> unit) -> GtkSignal.id
+    method notify_hover_selection : callback:(bool -> unit) -> GtkSignal.id
+    method notify_reorderable : callback:(bool -> unit) -> GtkSignal.id
+    method notify_rules_hint : callback:(bool -> unit) -> GtkSignal.id
+    method notify_search_column : callback:(int -> unit) -> GtkSignal.id
+    method notify_tooltip_column : callback:(int -> unit) -> GtkSignal.id
+    method notify_vadjustment : callback:(GData.adjustment -> unit) -> GtkSignal.id
   end
 
 (** A widget for displaying both trees and lists
@@ -398,6 +409,7 @@ class view : tree_view obj ->
       x:int -> y:int -> (tree_path * view_column * int * int) option
     method get_cell_area :
         ?path:tree_path -> ?col:view_column -> unit -> Gdk.Rectangle.t
+    method get_visible_range : unit -> (tree_path * tree_path) option
     method hadjustment : GData.adjustment
     method headers_visible : bool
     method insert_column : view_column -> int -> int
@@ -557,9 +569,10 @@ class cell_renderer_pixbuf : Gtk.cell_renderer_pixbuf obj ->
   end
 
 (** @gtkdoc gtk GtkCellRendererText *)
-class cell_renderer_text_signals : Gtk.cell_renderer_text obj ->
+class cell_renderer_text_signals : ([>Gtk.cell_renderer_text] as 'a) obj ->
   object
     inherit GObj.gtkobj_signals
+    val obj : 'a obj
     method edited : callback:(Gtk.tree_path -> string -> unit) -> GtkSignal.id
   end
 
@@ -593,12 +606,22 @@ class cell_renderer_progress : Gtk.cell_renderer_progress obj ->
     method connect : GObj.gtkobj_signals_impl
   end
 
+(** @since GTK 2.6
+    @gtkdoc gtk GtkCellRendererCombo *)
+class cell_renderer_combo_signals : ([>Gtk.cell_renderer_combo] as 'a) obj ->
+  object
+    inherit cell_renderer_text_signals
+    val obj : 'a obj
+    method changed :
+      callback:(Gtk.tree_path -> Gtk.tree_iter -> unit) -> GtkSignal.id
+  end
+
 (** @since GTK 2.6
     @gtkdoc gtk GtkCellRendererCombo *)
 class cell_renderer_combo : Gtk.cell_renderer_combo obj ->
   object
     inherit[Gtk.cell_renderer_combo,cell_properties_combo] cell_renderer_skel
-    method connect : cell_renderer_text_signals
+    method connect : cell_renderer_combo_signals
     method set_fixed_height_from_font : int -> unit
   end
 
@@ -655,6 +678,14 @@ class icon_view_signals : [> Gtk.icon_view] Gtk.obj ->
     inherit GContainer.container_signals
     method item_activated : callback:(Gtk.tree_path -> unit) -> GtkSignal.id
     method selection_changed : callback:(unit -> unit) -> GtkSignal.id
+    method notify_column_spacing : callback:(int -> unit) -> GtkSignal.id
+    method notify_columns : callback:(int -> unit) -> GtkSignal.id
+    method notify_item_width : callback:(int -> unit) -> GtkSignal.id
+    method notify_margin : callback:(int -> unit) -> GtkSignal.id
+    method notify_orientation : callback:(GtkEnums.orientation -> unit) -> GtkSignal.id
+    method notify_row_spacing : callback:(int -> unit) -> GtkSignal.id
+    method notify_selection_mode : callback:(GtkEnums.selection_mode -> unit) -> GtkSignal.id
+    method notify_spacing : callback:(int -> unit) -> GtkSignal.id
   end
 
 (** A widget which displays a list of icons in a grid
