@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gWindow.mli 1402 2008-03-25 08:55:03Z garrigue $ *)
+(* $Id$ *)
 
 open Gtk
 open GObj
@@ -191,9 +191,10 @@ class ['a] dialog_skel : ([>Gtk.dialog] as 'b) obj ->
 
 (** Create popup windows
    @gtkdoc gtk GtkDialog *)
-class ['a] dialog_ext : [> Gtk.dialog] obj ->
+class ['a] dialog_ext : ([> Gtk.dialog] as 'b) obj ->
   object
     inherit ['a] dialog_skel
+    val obj : 'b obj
     method add_button : string -> 'a -> unit
     method add_button_stock : GtkStock.id -> 'a -> unit
   end
@@ -203,6 +204,7 @@ class ['a] dialog_ext : [> Gtk.dialog] obj ->
 class ['a] dialog : [> Gtk.dialog] obj ->
   object
     inherit ['a] dialog_ext
+    val obj : Gtk.dialog obj
     method connect : 'a dialog_signals
   end
 
@@ -236,7 +238,6 @@ val dialog :
 type any_response = [GtkEnums.response | `OTHER of int]
 class dialog_any : [> Gtk.dialog] obj -> [any_response] dialog
 
-
 (** {3 GtkMessageDialog} *)
 
 type 'a buttons
@@ -309,6 +310,8 @@ class about_dialog :
     method license : string
     method logo : GdkPixbuf.pixbuf
     method logo_icon_name : string
+    (** The property [name] is left unchanged, but it will
+        access [program-name] if version is higher than 2.12 *)
     method name : string
     method translator_credits : string
     method version : string
@@ -351,13 +354,13 @@ let show_dialog () =
     @since GTK 2.6 
 *)
 val about_dialog :
+  ?name:string ->
   ?authors:string list ->
   ?comments:string ->
   ?copyright:string ->
   ?license:string ->
   ?logo:GdkPixbuf.pixbuf ->
   ?logo_icon_name:string ->
-  ?name:string ->
   ?translator_credits:string ->
   ?version:string ->
   ?website:string ->
