@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gtkData.ml 1369 2007-09-25 02:56:09Z garrigue $ *)
+(* $Id$ *)
 
 open Gaux
 open Gobject
@@ -34,25 +34,33 @@ module AccelGroup = struct
       = "ml_gtk_accel_group_lock"
   external unlock : accel_group -> unit
       = "ml_gtk_accel_group_unlock"
-  external connect_ :
+  external connect :
       accel_group -> key:Gdk.keysym -> ?modi:Gdk.Tags.modifier list ->
       ?flags:accel_flag list ->  callback:g_closure -> unit
       = "ml_gtk_accel_group_connect"
   let connect ~key ?modi ?flags ~callback g =
-    connect_ g ~key ?modi ?flags
+    connect g ~key ?modi ?flags
       ~callback:(Closure.create (fun _ -> callback ()))
   external disconnect :
       accel_group -> key:Gdk.keysym -> ?modi:Gdk.Tags.modifier list -> bool
       = "ml_gtk_accel_group_disconnect_key"
+  let disconnect ~key ?modi g = disconnect g ~key ?modi
   external groups_activate :
       'a obj -> key:Gdk.keysym -> ?modi:Gdk.Tags.modifier list -> bool
       = "ml_gtk_accel_groups_activate"
+  let groups_activate ~key ?modi obj = groups_activate obj ~key ?modi
+  (* XXX In the following functions, optional arguments are useless! *)
+  (* Should remove the key label in lablgtk3 ? *)
   external valid : key:Gdk.keysym -> ?modi:Gdk.Tags.modifier list -> bool
       = "ml_gtk_accelerator_valid"
   external set_default_mod_mask : Gdk.Tags.modifier list option -> unit
       = "ml_gtk_accelerator_set_default_mod_mask"
   external parse : string -> Gdk.keysym * Gdk.Tags.modifier list
       = "ml_gtk_accelerator_parse"
+  external name : key:Gdk.keysym -> ?modi:Gdk.Tags.modifier list -> string
+      = "ml_gtk_accelerator_name"
+  external get_label : key:Gdk.keysym -> ?modi:Gdk.Tags.modifier list -> string
+      = "ml_gtk_accelerator_get_label"
 end
 
 module AccelMap = struct
@@ -61,9 +69,18 @@ module AccelMap = struct
   external add_entry : 
     string -> 
     key:Gdk.keysym -> 
-    ?modi:Gdk.Tags.modifier list ->
-    unit = "ml_gtk_accel_map_add_entry"
-  let add_entry  ?(key=0) ?modi s = add_entry s ~key ?modi	     
+    ?modi:Gdk.Tags.modifier list -> unit
+    = "ml_gtk_accel_map_add_entry"
+  let add_entry  ?(key=0) ?modi s = add_entry s ~key ?modi
+  external change_entry :
+    string -> Gdk.keysym -> Gdk.Tags.modifier list option -> bool -> bool
+    = "ml_gtk_accel_map_change_entry"
+  let change_entry ?(key=0) ?modi ?(replace=true) s =
+    change_entry s key modi replace
+  external foreach :
+    (path:string -> key:int ->
+     modi:Gdk.Tags.modifier list -> changed:bool -> unit) -> unit
+    = "ml_gtk_accel_map_foreach"
 end
 
 module Style = struct
@@ -163,3 +180,4 @@ module Tooltips = struct
       [>`widget] obj -> ?text:string -> ?privat:string -> unit
       = "ml_gtk_tooltips_set_tip"
 end
+
