@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id: ml_gobject.c 1443 2009-01-20 09:49:48Z ben_99_9 $ */
+/* $Id$ */
 #include <stdio.h>
 #include <glib.h>
 #include <glib-object.h>
@@ -289,7 +289,7 @@ CAMLprim value Val_gboxed_new(GType t, gpointer p)
 
 #define DATA  (val->data[0])
 
-static value g_value_get_variant (GValue *val)
+static value g_value_get_mlvariant (GValue *val)
 {
     CAMLparam0();
     CAMLlocal1(tmp);
@@ -375,9 +375,9 @@ static value g_value_get_variant (GValue *val)
     CAMLreturn(ret);
 }
 
-ML_1 (g_value_get_variant, GValue_val, ID)
+ML_1 (g_value_get_mlvariant, GValue_val, ID)
 
-static void g_value_set_variant (GValue *val, value arg)
+static void g_value_set_mlvariant (GValue *val, value arg)
 {
     value tag = Field(arg,0);
     value data = Field(arg,1);
@@ -461,7 +461,7 @@ static void g_value_set_variant (GValue *val, value arg)
     return;
 }
 
-ML_2 (g_value_set_variant, GValue_val, ID, Unit)
+ML_2 (g_value_set_mlvariant, GValue_val, ID, Unit)
 
 CAMLprim value ml_g_value_get_nativeint(value arg) {
     GValue *val = GValue_val(arg);
@@ -532,7 +532,7 @@ CAMLprim value ml_g_object_new (value type, value params)
         pspec = g_object_class_find_property (class, param->name);
         if (!pspec) failwith ("Gobject.create");
         g_value_init (&param->value, pspec->value_type);
-        g_value_set_variant (&param->value, Field(Field(cell,0),1));
+        g_value_set_mlvariant (&param->value, Field(Field(cell,0),1));
         param++;
       }
     }
@@ -556,7 +556,7 @@ CAMLprim value ml_g_object_get_property_dyn (value vobj, value prop)
   if (tp == G_TYPE_INVALID) caml_invalid_argument(String_val(prop));
   g_value_init (&val, tp);
   g_object_get_property (obj, String_val(prop), &val);
-  ret = g_value_get_variant (&val);
+  ret = g_value_get_mlvariant (&val);
   g_value_unset (&val);
   return ret;
 }
@@ -568,7 +568,7 @@ CAMLprim value ml_g_object_set_property_dyn (value vobj, value prop, value arg)
   GValue val = {0};
   if (tp == G_TYPE_INVALID) return Val_unit; /* Silently ignore this error */
   g_value_init (&val, tp);
-  g_value_set_variant (&val, arg);
+  g_value_set_mlvariant (&val, arg);
   g_object_set_property (obj, String_val(prop), &val);
   g_value_unset (&val);
   return Val_unit;
@@ -576,6 +576,64 @@ CAMLprim value ml_g_object_set_property_dyn (value vobj, value prop, value arg)
 
 /* gsignal.h */
 
+#define Copy_GSignalQuery(ml_query, ml_params, query) \
+  ml_query = alloc_small(6, 0); \
+  ml_params = caml_alloc(query->n_params, 0); \
+  Store_field(ml_query, 0, Val_int(query->signal_id)); \
+  Store_field(ml_query, 1, caml_copy_string (query->signal_name)); \
+  Store_field(ml_query, 2, caml_copy_string (g_type_name(query->itype))); \
+  Store_field(ml_query, 3, Val_int(query->signal_flags)); \
+  Store_field(ml_query, 4, caml_copy_string (g_type_name(query->return_type)));\
+  for (i = 0; i < query->n_params; i++) \
+    Store_field(ml_params, i, Val_string(g_type_name(query->param_types[i]))); \
+  Store_field(ml_query, 5, ml_params)
+
+Make_Flags_val (Signal_type_val)
+
+CAMLprim value ml_g_signal_new_me(value o_name, value o_classe, value o_signal_flags) {
+  const gchar* name = String_val(o_name);
+  GSignalFlags signal_flags = Flags_Signal_type_val(o_signal_flags);
+  GType itype = GType_val(o_classe);
+
+  guint class_offset = 0;
+  GSignalAccumulator accumulator = NULL;
+  gpointer accu_data = NULL;
+  GSignalCMarshaller marshaller = g_cclosure_marshal_VOID__POINTER;
+  GType return_type = G_TYPE_NONE;
+  guint nparams = 0;
+  g_signal_new (name, itype, signal_flags, class_offset, accumulator, accu_data,
+      marshaller, return_type, nparams);
+  return (Val_int(0));
+}
+
+CAMLprim value ml_g_signal_query(value ml_i) {
+  CAMLparam1(ml_i);
+  CAMLlocal2(ml_query, ml_query_params);
+  GSignalQuery* query;
+  guint i = Int_val(ml_i);
+
+  query = malloc(sizeof(GSignalQuery));
+  g_signal_query(i, query);
+  if (query->signal_id == 0) invalid_argument("g_signal_query");
+
+  Copy_GSignalQuery(ml_query, ml_query_params, query);
+  free(query);
+
+  CAMLreturn(ml_query);
+}
+
+CAMLprim value ml_g_signal_list_ids(value type)
+{
+    CAMLparam1(type);
+    CAMLlocal1(ret);
+    guint n_ids;
+    guint *ids;
+    ids = g_signal_list_ids(GType_val(type), &n_ids);
+    Copy_array(ret, n_ids, ids, Val_int);
+    free(ids);
+    CAMLreturn(ret);
+}
+
 ML_4 (g_signal_connect_closure, GObject_val, String_val, GClosure_val,
       Bool_val, Val_long)
 ML_2 (g_signal_handler_block, GObject_val, Long_val, Unit)
@@ -611,7 +669,7 @@ CAMLprim value ml_g_signal_emit_by_name (value obj, value sig, value params)
     for (i = 0; i < query.n_params; i++) {
         g_value_init (&iparams[i+1],
                       query.param_types[i] & ~G_SIGNAL_TYPE_STATIC_SCOPE);
-        g_value_set_variant (&iparams[i+1], Field(params,i));
+        g_value_set_mlvariant (&iparams[i+1], Field(params,i));
     }
     g_signal_emitv (iparams, signal_id, detail, (ret ? GValue_val(ret) : 0));
     for (i = 0; i < query.n_params + 1; i++)
